<?php

namespace Cli\Assets;

trait Console
{
    use Colors;

    /**
     * @var false|resource
     */
    private $handle = false;

    /**
     * @param string $message
     * @param null $color
     * @param string $background
     */
    public function print(string $message, $color = null, $background = '')
    {
        echo $this->printColor($message, $color, $background);
    }

    /**
     * @param string $message
     * @param null $color
     * @param string $background
     */
    public function printLn(string $message, $color = null, $background = '')
    {
        $this->print($message, $color, $background);
        echo "\n";
    }

    /**
     * @param string $message
     */
    public function success(string $message)
    {
        $this->printLn($message, 'green');
    }

    /**
     * @param string $message
     */
    public function warning(string $message)
    {
        $this->printLn($message, 'brown');
    }

    /**
     * @param string $message
     */
    public function error(string $message)
    {
        $this->printLn($message, 'white', 'red');
    }

    /**
     * @param $question
     * @return string
     */
    public function ask($question)
    {
        $this->success($question );
        $this->print("  >  ", 'yellow');

        return $this->getLine();
    }

    /**
     * Terminate console
     */
    public function terminate()
    {
        exit(0);
    }

    /**
     * @return string
     */
    private function getLine()
    {
        if( $this->handle === false) {
            $this->handle = fopen("php://stdin","r");
        }

        return trim(fgets($this->handle));
    }

}