<?php

namespace Runtime\Exceptions;

use Whoops\Handler\Handler;
use Whoops\Handler\JsonResponseHandler;
use Whoops\Handler\PlainTextHandler;
use Whoops\Run;
use Whoops\Handler\PrettyPageHandler;
use Whoops\Util\Misc;

class ExceptionHandler {

    /**
     * @var Run
     */
    private static $handler;

    /**
     * @param null $abstract
     * @param null $message
     */
    public static function make($abstract = null, $message = null)
    {
        if(is_string($abstract)) {
            $abstract = new $abstract($message);
        }

        if(is_subclass_of($abstract, 'Exception')) {
            self::$handler->handleException($abstract);
        }

        die();
    }

    /**
     * Register Whoops (Error handler)
     */
    public static function register()
    {
        self::$handler = new Run();

        $debug = true; //TODO: Get from config

        if($debug === false) {
            self::$handler->pushHandler(function() {
                if(app()->view()->exist('errors.500')) {
                    echo app()->view()->render('errors.500');
                }
                return Handler::DONE;
            });
        }
        else {
            self::$handler->pushHandler(new PrettyPageHandler());
        }

        if (Misc::isAjaxRequest()){
            self::$handler->pushHandler(new JsonResponseHandler());
        }

        if (Misc::isCommandLine()){
            self::$handler->pushHandler(new PlainTextHandler());
        }

        self::$handler->register();
    }

}

