<?php

namespace Runtime\Http\View;

use Runtime\Factory\AppFactory;
use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Error\SyntaxError;
use Twig\Loader\FilesystemLoader;
use Twig\TwigFunction;

class ViewEngine extends AppFactory {

    /**
     * @var self
     */
    private static $instance;

    /**
     * @var Environment
     */
    private static $twig;

    public function __construct()
    {
        $loader = new FilesystemLoader(app()->resourcePath()  . 'views');

        self::$twig = new Environment($loader, [
            //'cache' => app()->resourcePath() . 'cache'
        ]);

        $this->loadHelperFunctions();

        self::$instance = $this;
    }

    /**
     * Load all helper functions as Twig Function
     */
    private function loadHelperFunctions()
    {
        $functions = $this->getHelperFunctions();

        foreach ($functions as $function)
        {
            $function = new TwigFunction($function, function (...$params) use ($function) {
                return call_user_func_array($function, $params);
            });

            self::$twig->addFunction($function);
        }
    }

    /**
     * @param $name
     * @param array $context
     * @return string
     * @throws LoaderError
     * @throws RuntimeError
     * @throws SyntaxError
     */
    public function render($name, array $context = [])
    {
        return self::$twig->render($this->name($name), $context);
    }

    /**
     * @param $name
     * @return bool
     */
    public function exist($name)
    {
        $template = app()->resourcePath() . 'views/' . $this->name($name);

        return file_exists($template);
    }

    /**
     * @param $name
     * @return string|string[]
     */
    private function name($name)
    {
        return str_replace('.', '/', $name) . '.twig';
    }

    /**
     * @return self
     */
    public static function get()
    {
        return self::$instance;
    }

}